@@ -281,6 +281,17 @@ DNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
     'DNASequencesDirectoryFormat', 'dna-sequences.fasta', DNAFASTAFormat)
 
 
+class MixedCaseDNAFASTAFormat(DNAFASTAFormat):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.alphabet = self.alphabet + self.alphabet.lower()
+
+
+MixedCaseDNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
+    'MixedCaseDNASequencesDirectoryFormat', 'dna-sequences.fasta',
+    MixedCaseDNAFASTAFormat)
+
+
 class RNAFASTAFormat(FASTAFormat):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -291,6 +302,17 @@ RNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
     'RNASequencesDirectoryFormat', 'rna-sequences.fasta', RNAFASTAFormat)
 
 
+class MixedCaseRNAFASTAFormat(RNAFASTAFormat):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.alphabet = self.alphabet + self.alphabet.lower()
+
+
+MixedCaseRNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
+    'MixedCaseRNASequencesDirectoryFormat', 'rna-sequences.fasta',
+    MixedCaseRNAFASTAFormat)
+
+
 class PairedDNASequencesDirectoryFormat(model.DirectoryFormat):
     left_dna_sequences = model.File('left-dna-sequences.fasta',
                                     format=DNAFASTAFormat)
@@ -316,6 +338,18 @@ AlignedDNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
     AlignedDNAFASTAFormat)
 
 
+class MixedCaseAlignedDNAFASTAFormat(AlignedFASTAFormatMixin,
+                                     MixedCaseDNAFASTAFormat):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        super()._turn_into_alignment()
+
+
+MixedCaseAlignedDNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
+    'MixedCaseAlignedDNASequencesDirectoryFormat',
+    'aligned-dna-sequences.fasta', MixedCaseAlignedDNAFASTAFormat)
+
+
 class AlignedRNAFASTAFormat(AlignedFASTAFormatMixin, RNAFASTAFormat):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -327,6 +361,18 @@ AlignedRNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
     AlignedRNAFASTAFormat)
 
 
+class MixedCaseAlignedRNAFASTAFormat(AlignedFASTAFormatMixin,
+                                     MixedCaseRNAFASTAFormat):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        super()._turn_into_alignment()
+
+
+MixedCaseAlignedRNASequencesDirectoryFormat = model.SingleFileDirectoryFormat(
+    'MixedCaseAlignedRNASequencesDirectoryFormat',
+    'aligned-rna-sequences.fasta', MixedCaseAlignedRNAFASTAFormat)
+
+
 def _construct_validator_from_alphabet(alphabet_str):
     if alphabet_str:
         Validator = re.compile(fr'[{alphabet_str}]+\r?\n?')
@@ -358,7 +404,7 @@ DifferentialDirectoryFormat = model.SingleFileDirectoryFormat(
 class ProteinFASTAFormat(FASTAFormat):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.alphabet = "ABCDEFGHIKLMNPQRSTVWXYZ"
+        self.alphabet = "ABCDEFGHIKLMNPQRSTVWXYZ*"
 
 
 ProteinSequencesDirectoryFormat = model.SingleFileDirectoryFormat(
@@ -405,5 +451,10 @@ plugin.register_formats(
     AlignedProteinSequencesDirectoryFormat, RNAFASTAFormat,
     RNASequencesDirectoryFormat, AlignedRNAFASTAFormat,
     AlignedRNASequencesDirectoryFormat, PairedRNASequencesDirectoryFormat,
-    BLAST6Format, BLAST6DirectoryFormat
+    BLAST6Format, BLAST6DirectoryFormat, MixedCaseDNAFASTAFormat,
+    MixedCaseDNASequencesDirectoryFormat, MixedCaseRNAFASTAFormat,
+    MixedCaseRNASequencesDirectoryFormat, MixedCaseAlignedDNAFASTAFormat,
+    MixedCaseAlignedDNASequencesDirectoryFormat,
+    MixedCaseAlignedRNAFASTAFormat,
+    MixedCaseAlignedRNASequencesDirectoryFormat
 )
