@@ -8,15 +8,16 @@
 
 import qiime2.plugin.model as model
 
+from ..per_sample_sequences import FastqGzFormat
+from ..feature_data import FASTAFormat, DNAFASTAFormat
+
 from ..plugin_setup import plugin
-from q2_types.per_sample_sequences import FastqGzFormat
 
 
 # MultiplexedSingleEndBarcodeInSequenceDirFmt &
 # MultiplexedPairedEndBarcodeInSequenceDirFmt represent multiplexed sequences
 # that contain inline barcode information:
 # AGGACTAGGTAGATC => barcode: AGGA ; biological sequence: CTAGGTAGATC
-
 MultiplexedSingleEndBarcodeInSequenceDirFmt = model.SingleFileDirectoryFormat(
     'MultiplexedSingleEndBarcodeInSequenceDirFmt', 'forward.fastq.gz',
     FastqGzFormat)
@@ -27,7 +28,22 @@ class MultiplexedPairedEndBarcodeInSequenceDirFmt(model.DirectoryFormat):
     reverse_sequences = model.File('reverse.fastq.gz', format=FastqGzFormat)
 
 
+class QualFormat(FASTAFormat):
+    # qual files (as in the 454 fasta/qual format) look like fasta files
+    # except that instead of sequence data they have space separated PHRED
+    # scores.
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.alphabet = "0123456789 "
+
+
+class MultiplexedFastaQualDirFmt(model.DirectoryFormat):
+    sequences = model.File('reads.fasta', format=DNAFASTAFormat)
+    quality = model.File('reads.qual', format=QualFormat)
+
+
 plugin.register_formats(
     MultiplexedSingleEndBarcodeInSequenceDirFmt,
     MultiplexedPairedEndBarcodeInSequenceDirFmt,
+    MultiplexedFastaQualDirFmt
 )
