@@ -33,13 +33,15 @@ from q2_types.per_sample_sequences import (
     PairedEndFastqManifestPhred33V2,
     PairedEndFastqManifestPhred64V2,
     QIIME1DemuxDirFmt,
-    FastqGzFormat)
+    FastqGzFormat,
+    SampleIdIndexedSingleEndPerSampleDirFmt)
 from q2_types.per_sample_sequences._util import (
     _validate_header,
     _validate_single_end_fastq_manifest_directions,
     _validate_paired_end_fastq_manifest_directions,
     _parse_and_validate_manifest
 )
+from qiime2.plugin import ValidationError
 from qiime2.plugin.testing import TestPluginBase
 
 
@@ -291,6 +293,39 @@ class TestTransformers(TestPluginBase):
 
         self.assertEqual(obs_fp, exp_fp)
 
+    def test_sample_id_indexed_fastq_to_slpssefdf_fmt(self):
+        filenames = ('Human-Armpit.fastq.gz',
+                     # regardless of how much the file name looks like
+                     # Casava, everything before the .fastq.gz should be
+                     # treated as the sample id
+                     'Human-Kneecap_S1_L001_R1_001.fastq.gz')
+        input, obs = self.transform_format(
+            SampleIdIndexedSingleEndPerSampleDirFmt,
+            SingleLanePerSampleSingleEndFastqDirFmt,
+            filenames=filenames
+        )
+
+        input.validate()
+
+        exp_fp = ['Human-Armpit_na_L001_R1_001.fastq.gz',
+                  'Human-Kneecap_S1_L001_R1_001_na_L001_R1_001.fastq.gz']
+        obs_fp = [str(fp) for fp, _ in obs.sequences.iter_views(FastqGzFormat)]
+        self.assertEqual(obs_fp, exp_fp)
+
+        manifest_df = obs.manifest.view(pd.DataFrame)
+        self.assertEqual(list(manifest_df.index),
+                         ['Human-Armpit', 'Human-Kneecap_S1_L001_R1_001'])
+
+    def test_sample_id_indexed_fastq_to_slpssefdf_fmt_bad_fastq(self):
+        filenames = ('Human-Armpit.fastq.gz',
+                     'invalid-quality.fastq.gz')
+        with self.assertRaisesRegex(ValidationError, 'Quality score length'):
+            self.transform_format(
+                SampleIdIndexedSingleEndPerSampleDirFmt,
+                SingleLanePerSampleSingleEndFastqDirFmt,
+                filenames=filenames
+            )
+
 
 class TestFastqManifestTransformers(TestPluginBase):
     package = "q2_types.per_sample_sequences.tests"
