@@ -19,7 +19,9 @@ AlphaDiversity = SemanticType('AlphaDiversity',
 
 plugin.register_semantic_types(SampleData, AlphaDiversity)
 
-plugin.register_semantic_type_to_format(
+plugin.register_artifact_class(
     SampleData[AlphaDiversity],
-    artifact_format=AlphaDiversityDirectoryFormat
+    directory_format=AlphaDiversityDirectoryFormat,
+    description=("Alpha diversity values, each associated with a single "
+                 "sample identifier.")
 )
